##Proposed Improvements to the Code:

After issuing the first version of the Open Code of Conduct, we received many suggestions to modify the text. Whereas we did not include all the suggestions, we did not want to lose them either, as they were made sincerely and may be applicable to many communities.

Below, we list some of the suggested edits to the Open Code of Conduct and offer them for your consideration. Your communities might wish to use these. As a project leader, you are in the best position to assess how helpful these will be for you. We’ll add our thoughts as to how you may apply them to your code.

####Clarity on Consequences.
We were asked to add the consequence-text taken from the [Geek Feminism Code of Conduct] (http://geekfeminism.org/about/code-of-conduct/): “_Anyone who violates this code of conduct may be banned from this community._” This could be added to Section 1 (Purpose). Alternatively, you may add to Section 6 (Consequences and Scope) the following “_Participants asked to stop any harassing behavior are expected to comply immediately. If an individual engages in unacceptable behavior, the representative may take any action they deem appropriate, up to and including a permanent ban from our community without warning._” Another consequence to consider adding: “_At our discretion, we may publicly name a person about whom we’ve received harassment complaints, or privately warn third parties about them._” 

Strong consequence text sends a clear message about the intent of a Code of Conduct, which is to keep people who misbehave out of a project. Whereas this is very useful, it might not always be in the scope of the project’s capabilities to enforce. We chose not to add the above text to our current version since we expect that some of the project leaders who wish to adopt our text are constrained by employment rules that could limit their ability to publicize the names of those accused of harassment, or they might be unable to enforce a user ban. However you may wish to include this or similar consequence-text explicitly for your community. Moreover, even if not explicitly stated, a Code of Conduct that does not include consequence text still implies that a Response Team will take approrpiate action in order to resolve an issue.

####A more elaborate list of conduct that is considered harassment.
In an attempt to be clearer, you may consider listing more explicit examples of harassment. For example, one of our earlier versions include the following, taken from the [Geek Feminism Code of Conduct] (http://geekfeminism.org/about/code-of-conduct/):
  * Offensive comments related to gender, gender identity and expression, sexual orientation, disability, mental illness, neuro(a)typicality, physical appearance, body size, race, age, regional discrimination, political or religious affiliation
  * Unwelcome comments regarding a person’s lifestyle choices and practices, including those related to food, health, parenting, drugs, and employment
  * Deliberate misgendering. This includes deadnaming or persistently using a pronoun that does not correctly reflect a person's gender identity. You must address people by the name they give you when not addressing them by their username or handle
  * Physical contact and simulated physical contact (eg, textual descriptions like “*hug*” or “*backrub*”) without consent or after a request to stop
  * Threats of violence, both physical and psychological
  * Incitement of violence towards any individual, including encouraging a person to commit suicide or to engage in self-harm
  * Deliberate intimidation
  * Stalking or following
  * Harassing photography or recording, including logging online activity for harassment purposes
  * Sustained disruption of discussion
  * Unwelcome sexual attention, including gratuitous or off-topic sexual images or behaviour
  * Pattern of inappropriate social contact, such as requesting/assuming inappropriate levels of intimacy with others
  * Continued one-on-one communication after requests to cease
  * Deliberate “outing” of any aspect of a person’s identity without their consent except as necessary to protect others from intentional abuse
  * Publication of non-harassing private communication

In our current version, we reduced the number of examples to the list you’ll find in Section 4 (Unaccepted Behaviors) of our current code. You can choose to expand upon this list, including some or all of the above based on relevance to your community. Not including this list does not imply these are acceptable behaviors. Rather, your code needs to balance clarity with brevity and relevance.

####A list of conduct excluded from the category of harassment. 
Given a list of harassment behaviors, we were asked to include a list of behaviors that the code does *not* consider to be harassment. You may wish to add “_We will not act on complaints regarding:_” and then list those items that you exclude.

For example, the following items are excluded from the [Geek Feminism Code of Conduct] (http://geekfeminism.org/about/code-of-conduct/).
  * ‘Reverse’ -isms, including ‘reverse racism,’ ‘reverse sexism,’ and ‘cisphobia’ 
  * Reasonable communication of boundaries, such as “leave me alone,” “go away,” or “I’m not discussing this with you.”
  * Refusal to explain or debate social justice concepts
  * Communicating in a ‘tone’ you don’t find congenial
  * Criticizing racist, sexist, cissexist, or otherwise oppressive behavior or assumptions

You could add a new section to explicitly elaborate exclusions, you could modify Section 4 (Unaccepted Behaviors), or you could add to Section 3 (Expected Behaviors) what you expect as appropriate responses to the above behaviors. 

We chose to leave the section out of the Open Code of Conduct since we wished to start with a more expansive set and then pare it down when needed. Your community may chose a more limited scope of behaviors you are willing to address, thus assuring that some complaints, such as those related to reverse-isms, would not be honored.

####Dispute resolution processes.
Although our first version did not include suggestions for how disputing parties could work things out without raising a complaint, some people suggested that we clarify that we did not suggest that disputing parties should simply “work things out on their own.” We agree that telling people to "work things out on their own" is not an effective resolution process. 

The [Django Project Code of Conduct Enforcement Manual] (https://www.djangoproject.com/conduct/enforcement-manual/) contains a detail list of resolutions that range from doing nothing, to public apologies, to permanent bans. You may consider adding text to Section 6 (Consequences and Scope) or a new section where you list the resolutions that your community sees as appropriate. You may consider specifying, as they do, the process for enforcing and reporting resolutions, as well as the expected timeframes for each step of the process. 

####Prohibiting complaints “on-behalf-of” others. 
It was suggested to us that the Code of Conduct explicitly prohibit complaints that refer to misconduct that is witnessed but not experienced. We were unsure where this exclusion best applies. On the one hand, if there is witnessed harassment, the project leadership might want to know about it and take proactive steps to protect the victim as well as negative consequences to the project. On the other hand, allowing non-participating parties to register complaints may open the door to complaint-abuse where people create fake issues for the purpose of griefing others on the project. We leave it up to you to decide if you want to add an exclusion to 3rd party reports. If so, please edit the first line of Section 5 (Reporting Issues) to remove the “_or witness_” text and then add an clarification that reports are only accepted by people who are involved in the incident.

####Explicit condemnation of tone policing. 
A _Tone Argument_, [as defined here] (http://geekfeminism.wikia.com/wiki/Tone_argument), is an expression of concern regarding the tone of someone’s argument -- e.g. that they are being argumentative and could be more convincing if they worded their statements in a more civil tone. It was suggested that our Code of Conduct explicitly condemn calling out tonality as an area of concern that would justify a complaint. In other words, if a person feels harassed by someone who expresses themselves in an uncivil tone, that the code should refuse to acknowledge that complaint as valid since it only calls attention to the tone of a statement, not the statement itself.

Our current version of the code lists civil and professional tone as an expected behavior. This implies that uncivil tone toward project members may be raised as a valid misconduct issue. If you wish to remove tone policing as a valid concern, you can add this in the list of excluded harassment types and edit the list of expected behaviors to remove text related to civility, professional tone, and careful word selection. We believe that project leaders can set the expectations for what they consider acceptable tone in their community. So we'll state the position in our code that tonality matters, and offer this altnerative if you prefer your community to operate with a different standard.

####Prioritization of the complaints from marginalized people over those of the privileged. 
This suggestion comes from language found in the [Geek Feminism Code of Conduct] (http://geekfeminism.org/about/code-of-conduct/). Prioritization implies the comparison of two independent reports, but could also refer to biases applied to two parties involved in one dispute. 

You can add a section to your code describing how reports are prioritized, and if biases are applied to complaints from some members of your community. Our current version does not elaborate on how the Response Team should handle the request queue. You may elect a strict approach where requests addressed in the order they are received. You may empower your Response Team to use their discretion to determine what they perceive is a high-priority item and address it before resolving an older item. 

If you wish, you can adopt a categorical prioritization where issues are marked with severity levels that imply the impact of the issue to the project, or the priority given to some members of your community over others. We opted not to specify how Reponse Teams prioritize their work or if they should address complaints from some members ahead of those from others. We suggest that making this explicit sends a clear signal to your community about how they should expect complaints to be handled. If you do express a prioritization, we suggest to include clear definitions so that people understand and agree upon who fits into which category, since you can't assume that everyone sees things the same way. e.g. If you declare that you prioritize the issues made by active committers over those of lurkers, then you should include an objective definition of each category so that you don't add more concflict to your conflict resolution process.

####Including in-scope statements made outside of the context of the community. 
It was  suggested that we expand the scope of the code to include harassment incidents that takes place outside the community as sufficient grounds to cause action within the community. This was inspired by language found in the [Geek Feminism Code of Conduct] (http://geekfeminism.org/about/code-of-conduct/). Moreover, we were given a use case to consider based on a recent event in the Opal open source community where a request was made by someone who was not a participant of the community to remove a member from the community who posted a comment on Twitter that upset her. As these situations do arise, it is wise to consider how your community would address these cases.

You may wish to expand or restrict the scope of your Code of Conduct to address the following situations: 
  * If a member of the community harasses another member of the community outside of the context of the community (e.g. in personal or public forums)
  * If a member of the community harasses a non-member of the community, and the non-member registers a complaint with the project requesting the member to be banned from the community
  * If a member of the community offends a non-member of the community using the community forum to do so
  * If a member of the community offends a non-member on an external forum
  * and other cases to include or exclude from the scope of your code.

We leave the decision to the project leader to express the scope that you are willing to take for your projects. We focused the text of our current version to cover actions that take place by project members on the project forums engaging with other project memebers. If this scope is too limiting for your community, include a revision in Section 6 (Consequences and Scope) to indicate how you'd address the other in-scope situations.

####Other suggestions not listed
Whereas we recieved other suggestions to add to the code of conduct we are not listing them here since we did not see those on any other Code of Conduct. That said, our text is, and has always been, intended to stimulate a conversation about conduct in open source communities, and how to best address conduct issues explicitly. If your conversations result in suggestions for us, kindly let us know and we'll consider adding them here as a suggestion, and potentially in a subsequent version of the code text too.
